from blocks_genesis.database.db_context_provider import DbContextProvider


class DbContext:
    """
    Singleton class for managing a global DbContextProvider.
    """

    _provider: DbContextProvider = None

    @staticmethod
    def set_provider(provider: DbContextProvider) -> None:
        """
        Set the global DB context provider.

        Args:
            provider: An instance of DbContextProvider to use globally.
        """
        DbContext._provider = provider

    @staticmethod
    def get_provider() -> DbContextProvider:
        """
        Get the global DB context provider.

        Returns:
            The configured DbContextProvider.

        Raises:
            RuntimeError: If no provider has been set.
        """
        if DbContext._provider is None:
            raise RuntimeError("No DbContextProvider registered.")
        return DbContext._provider

    @staticmethod
    def clear() -> None:
        """
        Clear the global DB context provider.
        """
        DbContext._provider = None



import asyncio
import logging
import sys

from blocks_genesis.core.worker import WorkerConsoleApp


logger = logging.getLogger(__name__)


def main():
    app = WorkerConsoleApp("blocks_ai_worker")

    try:
        asyncio.run(app.run())
    except KeyboardInterrupt:
        logger.exception("\n👋 Graceful shutdown by user")
    except Exception as e:
        logger.exception(f"💥 Fatal error: {e}", file=sys.stderr)
        sys.exit(1)


if __name__ == "__main__":
    main()



from dataclasses import dataclass
import logging
from contextlib import asynccontextmanager
from fastapi import FastAPI
from blocks_genesis.auth.auth import authorize
from blocks_genesis.core.api import close_lifespan, configure_lifespan, configure_middlewares
from blocks_genesis.message.azure.azure_message_client import AzureMessageClient
from blocks_genesis.message.consumer_message import ConsumerMessage



logger = logging.getLogger(__name__)


@asynccontextmanager
async def lifespan(app: FastAPI):
    await configure_lifespan("blocks_ai_api")
    logger.info("✅ All services initialized!")

    yield  # app running here

    await close_lifespan()
    logger.info("🛑 App shutting down...")



app = FastAPI(lifespan=lifespan, debug=True)

# Add middleware in order
configure_middlewares(app);






@app.get("/")
async def root():
    logger.info("Root endpoint accessed")
    client = AzureMessageClient.get_instance()
    await client.send_to_consumer_async(ConsumerMessage(
        consumer_name="ai_queue",
        payload= AiMessage("Hello from AI API!"),
    ))
    return {"message": "Hello World", "secrets_loaded": True}



@app.get("/health", dependencies=[authorize(bypass_authorization=True)])
async def health():
    return {
        "status": "healthy",
        "secrets_status": "loaded" ,
    }
    
  
    
    
@dataclass
class AiMessage:
    message: str

